@@ -30,6 +30,8 @@ __docformat__ = 'restructuredtext'
 
 import os
 import sys
+import warnings
+
 from roundup import configuration, mailgw
 from roundup import hyperdb, backends, actions
 from roundup.cgi import client, templating
@@ -61,12 +63,36 @@ class Tracker:
         self.libdir = os.path.isdir(libdir) and libdir or ''
 
         self.load_interfaces()
-        self.templates = templating.get_templates(self.config["TEMPLATES"],
+        self.templates = templating.get_loader(self.config["TEMPLATES"],
             self.config["TEMPLATE_ENGINE"])
-        self.backend = backends.get_backend(self.get_backend_name())
+
+        rdbms_backend = self.config.RDBMS_BACKEND
+
+        # TODO: Remove in v1.7
+        # Provide some backwards compatability for existing Roundup instances
+        # that still define the backend type in 'db/backend_name' and warn the
+        # users they need to update their config.ini
+        if rdbms_backend == '':
+            filename = os.path.join(self.config.DATABASE, 'backend_name')
+            msg = """\n
+The 'backend_name' file is no longer used to configure the database backend
+used for the tracker.  Please read 'doc/upgrading.txt' to find out how to
+update your config.ini
+"""
+            try:
+                with file(filename) as backend_file:
+                    rdbms_backend = backend_file.readline().strip()
+
+                with warnings.catch_warnings():
+                    warnings.simplefilter("once", DeprecationWarning)
+                    warnings.warn(msg, DeprecationWarning, stacklevel=2)
+            except IOError:
+                pass
+
+        self.backend = backends.get_backend(rdbms_backend)
 
         if self.optimize:
-            self.templates.precompileTemplates()
+            self.templates.precompile()
             # initialize tracker extensions
             for extension in self.get_extensions('extensions'):
                 extension(self)
@@ -77,12 +103,6 @@ class Tracker:
             # db_open is set to True after first open()
             self.db_open = 0
 
-    def get_backend_name(self):
-        f = file(os.path.join(self.config.DATABASE, 'backend_name'))
-        name = f.readline().strip()
-        f.close()
-        return name
-
     def open(self, name=None):
         # load the database schema
         # we cannot skip this part even if self.optimize is set
@@ -101,6 +121,7 @@ class Tracker:
             'Interval': hyperdb.Interval,
             'Boolean': hyperdb.Boolean,
             'Number': hyperdb.Number,
+            'Integer': hyperdb.Integer,
             'db': backend.Database(self.config, name)
         }
 
@@ -121,6 +142,8 @@ class Tracker:
                 extension(self)
             detectors = self.get_extensions('detectors')
         db = env['db']
+        db.tx_Source = None
+
         # apply the detectors
         for detector in detectors:
             detector(db)
@@ -186,8 +209,9 @@ class Tracker:
             sys.path.remove(dirpath)
         return extensions
 
-    def init(self, adminpw):
+    def init(self, adminpw, tx_Source=None):
         db = self.open('admin')
+        db.tx_Source = tx_Source
         self._execfile('initial_data.py', {'db': db, 'adminpw': adminpw,
             'admin_email': self.config['ADMIN_EMAIL']})
         db.commit()
@@ -233,7 +257,7 @@ class Tracker:
     def registerUtil(self, name, function):
         self.templating_utils[name] = function
 
-class TrackerError(Exception):
+class TrackerError(BaseException):
     pass
 
 
@@ -288,9 +312,9 @@ class OldStyleTrackers:
         tracker.dbinit.config = tracker.config
 
         tracker.optimize = optimize
-        tracker.templates = templating.Templates(tracker.config["TEMPLATES"])
+        tracker.templates = templating.get_loader(tracker.config["TEMPLATES"])
         if optimize:
-            tracker.templates.precompileTemplates()
+            tracker.templates.precompile()
 
         return tracker
 
