@@ -4,13 +4,14 @@
 # For license terms see the file COPYING.txt.
 #
 
+import logging
 from roundup import hyperdb
-from roundup.cgi.exceptions import *
-from roundup.exceptions import UsageError
+from roundup.exceptions import Unauthorised, UsageError
 from roundup.date import Date, Range, Interval
 from roundup import actions
-from SimpleXMLRPCServer import *
+from SimpleXMLRPCServer import SimpleXMLRPCDispatcher
 from xmlrpclib import Binary
+from traceback import format_exc
 
 def translate(value):
     """Translate value to becomes valid for XMLRPC transmission."""
@@ -50,10 +51,14 @@ def props_from_args(db, cl, args, itemid=None):
             try:
                 props[key] = hyperdb.rawToHyperdb(db, cl, itemid,
                                                   key, value)
-            except hyperdb.HyperdbValueError, message:
+            except hyperdb.HyperdbValueError as message:
                 raise UsageError, message
         else:
-            props[key] = None
+            # If we're syncing a file the contents may not be None
+            if key == 'content':
+                props[key] = ''
+            else:
+                props[key] = None
 
     return props
 
@@ -147,8 +152,12 @@ class RoundupInstance:
         try:
             result = cl.create(**props)
             self.db.commit()
-        except (TypeError, IndexError, ValueError), message:
-            raise UsageError, message
+        except (TypeError, IndexError, ValueError) as message:
+            # The exception we get may be a real error, log the traceback if we're debugging
+            logger = logging.getLogger('roundup.xmlrpc')
+            for l in format_exc().split('\n'):
+                logger.debug(l)
+            raise UsageError (message)
         return result
 
     def set(self, designator, *args):
@@ -164,8 +173,12 @@ class RoundupInstance:
         try:
             result = cl.set(itemid, **props)
             self.db.commit()
-        except (TypeError, IndexError, ValueError), message:
-            raise UsageError, message
+        except (TypeError, IndexError, ValueError) as message:
+            # The exception we get may be a real error, log the traceback if we're debugging
+            logger = logging.getLogger('roundup.xmlrpc')
+            for l in format_exc().split('\n'):
+                logger.debug(l)
+            raise UsageError (message)
         return result
 
 
@@ -190,14 +203,9 @@ class RoundupDispatcher(SimpleXMLRPCDispatcher):
 
     def __init__(self, db, actions, translator,
                  allow_none=False, encoding=None):
-
-        try:
-            # python2.5 and beyond
-            SimpleXMLRPCDispatcher.__init__(self, allow_none, encoding)
-        except TypeError:
-            # python2.4
-            SimpleXMLRPCDispatcher.__init__(self)
+        SimpleXMLRPCDispatcher.__init__(self, allow_none, encoding)
         self.register_instance(RoundupInstance(db, actions, translator))
+        self.register_multicall_functions()
                  
 
     def dispatch(self, input):
