@@ -42,11 +42,14 @@ def copy_user(home1, home2, *userids):
     db1 = instance1.open('admin')
     db2 = instance2.open('admin')
 
+    db1.tx_Source = "cli"
+    db2.tx_Source = "cli"
+
     userlist = db1.user.list()
     for userid in userids:
         try:
             userid = str(int(userid))
-        except ValueError, why:
+        except ValueError as why:
             print "Not a numeric user id: %s  Skipping ..." % (userid,)
             continue
         if userid not in userlist:
@@ -62,7 +65,7 @@ def copy_user(home1, home2, *userids):
             db2.user.lookup(user['username'])
             print "User %s: Username '%s' exists in target instance. Skipping ..." % (userid, user['username'])
             continue
-        except KeyError, why:
+        except KeyError as why:
             pass
         print "Copying user %s (%s) ..." % (userid, user['username'])
         db2.user.create(**user)
