@@ -20,6 +20,7 @@ from roundup.backends import get_backend, have_backend
 
 from db_test_base import DBTest, ROTest, SchemaTest, ClassicInitTest, config
 from db_test_base import ConcurrentDBTest, FilterCacheTest
+from db_test_base import SpecialActionTest
 
 class sqliteOpener:
     if have_backend('sqlite'):
@@ -28,45 +29,35 @@ class sqliteOpener:
     def nuke_database(self):
         shutil.rmtree(config.DATABASE)
 
-class sqliteDBTest(sqliteOpener, DBTest):
+
+class sqliteDBTest(sqliteOpener, DBTest, unittest.TestCase):
     pass
 
-class sqliteROTest(sqliteOpener, ROTest):
+
+class sqliteROTest(sqliteOpener, ROTest, unittest.TestCase):
     pass
 
-class sqliteSchemaTest(sqliteOpener, SchemaTest):
+
+class sqliteSchemaTest(sqliteOpener, SchemaTest, unittest.TestCase):
     pass
 
-class sqliteClassicInitTest(ClassicInitTest):
+
+class sqliteClassicInitTest(ClassicInitTest, unittest.TestCase):
     backend = 'sqlite'
 
-class sqliteConcurrencyTest(ConcurrentDBTest):
+
+class sqliteConcurrencyTest(ConcurrentDBTest, unittest.TestCase):
     backend = 'sqlite'
 
-class sqliteFilterCacheTest(sqliteOpener, FilterCacheTest):
+
+class sqliteFilterCacheTest(sqliteOpener, FilterCacheTest, unittest.TestCase):
     backend = 'sqlite'
 
-from session_common import RDBMSTest
-class sqliteSessionTest(sqliteOpener, RDBMSTest):
+class sqliteSpecialActionTestCase(sqliteOpener, SpecialActionTest,
+                                  unittest.TestCase):
+    backend = 'sqlite'
+
+
+from session_common import SessionTest
+class sqliteSessionTest(sqliteOpener, SessionTest, unittest.TestCase):
     pass
-
-def test_suite():
-    suite = unittest.TestSuite()
-    from roundup import backends
-    if not have_backend('sqlite'):
-        print 'Skipping sqlite tests'
-        return suite
-    print 'Including sqlite tests'
-    suite.addTest(unittest.makeSuite(sqliteDBTest))
-    suite.addTest(unittest.makeSuite(sqliteROTest))
-    suite.addTest(unittest.makeSuite(sqliteSchemaTest))
-    suite.addTest(unittest.makeSuite(sqliteClassicInitTest))
-    suite.addTest(unittest.makeSuite(sqliteSessionTest))
-    suite.addTest(unittest.makeSuite(sqliteConcurrencyTest))
-    suite.addTest(unittest.makeSuite(sqliteFilterCacheTest))
-    return suite
-
-if __name__ == '__main__':
-    runner = unittest.TextTestRunner()
-    unittest.main(testRunner=runner)
-
